CsiConfig

Struct CsiConfig 

pub struct CsiConfig {
    pub enable: u32,
    pub acquire_csi_legacy: u32,
    pub acquire_csi_ht20: u32,
    pub acquire_csi_ht40: u32,
    pub acquire_csi_su: u32,
    pub acquire_csi_mu: u32,
    pub acquire_csi_dcm: u32,
    pub acquire_csi_beamformed: u32,
    pub acquire_csi_he_stbc: u32,
    pub val_scale_cfg: u32,
    pub dump_ack_en: u32,
    pub reserved: u32,
}
Available on crate features csi and unstable only.
Channel state information (CSI) configuration.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Fields

enable: u32

Enable to acquire CSI.

acquire_csi_legacy: u32

Enable to acquire L-LTF when receiving a 11g PPDU.

acquire_csi_ht20: u32

Enable to acquire HT-LTF when receiving an HT20 PPDU.

acquire_csi_ht40: u32

Enable to acquire HT-LTF when receiving an HT40 PPDU.

acquire_csi_su: u32

Enable to acquire HE-LTF when receiving an HE20 SU PPDU.

acquire_csi_mu: u32

Enable to acquire HE-LTF when receiving an HE20 MU PPDU.

acquire_csi_dcm: u32

Enable to acquire HE-LTF when receiving an HE20 DCM applied PPDU.

acquire_csi_beamformed: u32

Enable to acquire HE-LTF when receiving an HE20 Beamformed applied PPDU.

acquire_csi_he_stbc: u32

When receiving an STBC applied HE PPDU, 0- acquire the complete HE-LTF1, 1- acquire the complete HE-LTF2, 2- sample evenly among the HE-LTF1 and HE-LTF2.

val_scale_cfg: u32

Value 0-3.

dump_ack_en: u32

Enable to dump 802.11 ACK frame, default disabled.

reserved: u32

Reserved.